%% basics (Spring 2015)

%% iminfo
% info = imfinfo(filename) returns a structure whose fields contain
% information about an image in a graphics file. 
% filename is a string that specifies the name of the graphics file

filename = '2013_0115_163116AA.JPG';
info = imfinfo(filename);
disp(info)
% which leads us to enter:

info.DigitalCamera

info.ExifThumbnail

%% imread
% A = imread(filename) reads a grayscale or color image from the file 
% specified by the string filename. 

rgb = imread(filename);
whos rgb

%% imshow
% imshow(RGB) displays the truecolor image RGB.

small = imresize(rgb,0.3);
imshow(small);

%% imcrop
% I = imcrop creates an interactive Crop Image tool associated with the
% image displayed in the current figure, called the target image. 
% The Crop Image tool is a moveable, resizable rectangle that you can 
% position interactively using the mouse.

imshow(rgb);
[out rect] = imcrop;
rect

%% imwrite
% imwrite(A,filename) writes the image A to the file specified 
% by filename in the format specified the file extension.

imwrite(out,'cropped_target.jpg');
imshow(out);

%% rgb2gray 
% I = rgb2gray(RGB) converts the truecolor image RGB to 
% a grayscale intensity image I. 
% rgb2gray converts RGB images to grayscale by eliminating the hue and 
% saturation information while retaining the luminance.

g = rgb2gray(out);
imshow(g);

%% imhist
% imhist(I) displays a histogram for the image I above 
% a grayscale colorbar. The number of bins in the histogram is 
% specified by the image type. If I is a grayscale image, imhist uses 
% a default value of 256 bins. 

imhist(g);

%% graythresh and im2bw
% level = graythresh(I) computes a global threshold (level) that 
% can be used to convert an intensity image to a binary image with im2bw. 
% level is a normalized intensity value that lies in the range [0, 1].
%
%The graythresh function uses Otsu's method, which chooses the threshold
% to minimize the intraclass variance of the black and white pixels.

level = graythresh(g);
fprintf('threshold %g\n',level);
BW = im2bw(g,level);
imshow(BW);

%% bwconncomp
% CC = bwconncomp(BW) returns the connected components CC found in BW. 
% The binary image BW can have any dimension. 
% CC is a structure with four fields.

CC = bwconncomp(~BW);
disp(CC)


%% labelmatrix
% L = labelmatrix(CC) creates a label matrix from the connected components 
% structure CC returned by bwconncomp. The size of L is CC.ImageSize. 
% The elements of L are integer values greater than or equal to 0. 

L = labelmatrix(CC);

%% label2rgb
% RGB = label2rgb(L) converts a label matrix into an RGB color image 
% for the purpose of visualizing the labeled regions. 

RGB = label2rgb(L);
imshow(RGB);


%% simple mask operations
% show "inbetween" values;

msk1 = g>100;
msk2 = g<150;
imshow(msk1.*msk2);
